ensure policies are not pushed until drools is up

Change-Id: I6706fb126ea60abdfb0c540d07b305b8305d0b65
Issue-ID: POLICY-295
Signed-off-by: Jorge Hernandez <jh1730@att.com>
diff --git a/policy-pe/do-start.sh b/policy-pe/do-start.sh
index 49ddf25..ab8e5a1 100644
--- a/policy-pe/do-start.sh
+++ b/policy-pe/do-start.sh
@@ -77,7 +77,7 @@
 
 policy.sh start
 
 # on pap, wait for pap, pdp, brmsgw, and nexus up,
 # then push the initial default policies
 if [[ $container == pap ]]; then
 	./wait-for-port.sh pap 9091
@@ -85,6 +85,7 @@
 	# brmsgw doesn't have a REST API, so check for JMX port instead
 	./wait-for-port.sh brmsgw 9989
 	./wait-for-port.sh nexus 8081
+	./wait-for-port.sh drools 6969
 	# wait addional 1 minute for all processes to get fully initialized and synched up
 	sleep 60
 	bash -xv config/push-policies.sh
@@ -77,7 +77,7 @@
 policy.sh start
 
-# on pap, wait for pap, pdp, brmsgw, and nexus up,
+# on pap, wait for pap, pdp, brmsgw, nexus and drools up,
 # then push the initial default policies
 if [[ $container == pap ]]; then